@@ -20,16 +20,22 @@ pub(crate) struct Node {
 }
 
 impl Trie {
-    pub fn add(&mut self, word: &str, typ: Type, overwrite: bool) {
+    pub fn add(&mut self, mut word: &str, typ: Type, overwrite: bool) {
         let mut current = &mut self.root;
         let mut contains_space = false;
+        if word.starts_with(' ') {
+            // Chomp the first space, since what we actually want is to only match separate
+            // strings, not only strings that start with a space character.
+            contains_space = true;
+            word = word.trim_start_matches(' ');
+        }
         for (i, c) in word.chars().enumerate() {
             let next = current.children.entry(c);
             contains_space |= c == ' ';
             current = next.or_insert_with(|| Node {
                 children: FxHashMap::default(),
                 word: false,
-                contains_space,
+                contains_space: false,
                 typ: Type::NONE,
                 depth: (i + 1) as u8,
                 #[cfg(feature = "trace")]
@@ -39,8 +45,10 @@ impl Trie {
         current.word = true;
         if overwrite {
             current.typ = typ;
+            current.contains_space = contains_space;
         } else {
             current.typ |= typ;
+            current.contains_space |= contains_space;
         }
         debug_assert!(
             !(current.typ.is(Type::ANY) && current.typ.is(Type::SAFE)),
